from sohstationviewer.view.db_config.value_color_helper.functions import (
    convert_value_color_str, prepare_value_color_html
)

from tests.base_test_case import BaseTestCase


class TestConvertValueColorStr(BaseTestCase):
    def test_lines_dots(self):
        with self.subTest("Old format of both line and dot value"):
            expected_value_colors = "Line:#00FF00|Dot:#00FF00"
            result = convert_value_color_str('linesDots', 'L:G|D:G')
            self.assertEqual(result, expected_value_colors)
        with self.subTest("Old format of line value"):
            expected_value_colors = "Line:#00FF00"
            result = convert_value_color_str('linesDots', 'L:G')
            self.assertEqual(result, expected_value_colors)
        with self.subTest("Old format of default value which is empty string"):
            expected_value_colors = ""
            result = convert_value_color_str('linesDots', '')
            self.assertEqual(result, expected_value_colors)
        with self.subTest("New format of both line and dot value"):
            expected_value_colors = "Line:#00FF00|Dot:#00FF00"
            result = convert_value_color_str('linesDots',
                                             "Line:#00FF00|Dot:#00FF00")
            self.assertEqual(result, expected_value_colors)
        with self.subTest("New format of line value"):
            expected_value_colors = "Line:#00FF00"
            result = convert_value_color_str('linesDots', "Line:#00FF00")
            self.assertEqual(result, expected_value_colors)

    def test_up_down_dots(self):
        with self.subTest("Old format"):
            expected_value_colors = "Down:#FF0000|Up:#00FF00"
            result = convert_value_color_str('upDownDots', '0:R|1:G')
            self.assertEqual(result, expected_value_colors)
        with self.subTest("New format"):
            expected_value_colors = "Down:#FF0000|Up:#00FF00"
            result = convert_value_color_str('upDownDots',
                                             "Down:#FF0000|Up:#00FF00")
            self.assertEqual(result, expected_value_colors)

    def test_multi_color_dots_equal_on_upper_bound(self):
        with self.subTest("Old format"):
            expected_value_colors = ('<=0:not plot|<=1:#FFFF00|<=2:#00FF00'
                                     '|2<:#FF00FF')
            result = convert_value_color_str(
                'multiColorDotsEqualOnUpperBound',
                '0:_|1:Y|2:G|+2:M')
            self.assertEqual(result, expected_value_colors)
        with self.subTest("New format"):
            expected_value_colors = ('<=0:not plot|<=1:#FFFF00|<=2:#00FF00'
                                     '|2<:#FF00FF')
            result = convert_value_color_str(
                'multiColorDotsEqualOnUpperBound',
                '<=0:not plot|<=1:#FFFF00|<=2:#00FF00|2<:#FF00FF')
            self.assertEqual(result, expected_value_colors)

    def test_multi_color_dots_equal_on_lower_bound(self):
        with self.subTest("Old format"):
            expected_value_colors = '<3:#FF0000|<3.3:#FFFF00|=3.3:#00FF00'
            result = convert_value_color_str(
                'multiColorDotsEqualOnLowerBound',
                '3:R|3.3:Y|=3.3:G')
            self.assertEqual(result, expected_value_colors)
            with self.subTest("New format"):
                expected_value_colors = '<3:#FF0000|<3.3:#FFFF00|=3.3:#00FF00'
                result = convert_value_color_str(
                    'multiColorDotsEqualOnLowerBound',
                    '<3:#FF0000|<3.3:#FFFF00|=3.3:#00FF00')
                self.assertEqual(result, expected_value_colors)

    def test_tri_color_lines(self):
        with self.subTest("Old format"):
            expected_value_colors = '-1:#FF00FF|0:#FF0000|1:#00FF00'
            result = convert_value_color_str(
                'triColorLines',
                '-1:M|0:R|1:G')
            self.assertEqual(result, expected_value_colors)
        with self.subTest("New format"):
            expected_value_colors = '-1:#FF00FF|0:#FF0000|1:#00FF00'
            result = convert_value_color_str(
                'triColorLines',
                '-1:#FF00FF|0:#FF0000|1:#00FF00')
            self.assertEqual(result, expected_value_colors)

    def test_incorrect_format(self):
        with self.subTest("triColorLines"):
            with self.assertRaises(ValueError):
                convert_value_color_str(
                    'triColorLines',
                    '=1:M|*0:R|1.1:G')
        with self.subTest("upDownDots"):
            with self.assertRaises(ValueError):
                convert_value_color_str(
                    'upDownDots',
                    '2:M|Line:R|1.1:G|L:Y')
        with self.subTest("linesDots"):
            with self.assertRaises(ValueError):
                convert_value_color_str(
                    'linesDots',
                    '1:M|Up:R|1.1:G|L:Y')
        with self.subTest("multiColorDotsEqualOnUpperBound"):
            with self.assertRaises(ValueError):
                convert_value_color_str(
                    'multiColorDotsEqualOnUpperBound',
                    '*3:#FF0000|<3.3:#FFFF00|=3.3:#00FF00')
        with self.subTest("multiColorDotsEqualOnLowerBound"):
            with self.assertRaises(ValueError):
                convert_value_color_str(
                    'multiColorDotsEqualOnLowerBound',
                    '+0:R|-1:Y|<=2:G|2<:M')

    def test_old_value_color_str_is_empty(self):
        result = convert_value_color_str('linesSRate', '')
        self.assertEqual(result, '')


class TestPrepareValueColorHTML(BaseTestCase):
    def test_lines_dots(self):
        with self.subTest("Line and dot values"):
            expected_value_colors = (
                "<p>Line:"
                "<span style='color: #00FF00; font-size:25px;'>&#8718;</span>"
                "|Dot:"
                "<span style='color: #00FF00; font-size:25px;'>&#8718;</span>"
                "</p>")
            result = prepare_value_color_html("Line:#00FF00|Dot:#00FF00")
            self.assertEqual(result, expected_value_colors)
        with self.subTest("Line value"):
            expected_value_colors = (
                "<p>Line:<span style='color: #00FF00; font-size:25px;'>&#8718;"
                "</span></p>")
            result = prepare_value_color_html("Line:#00FF00")
            self.assertEqual(result, expected_value_colors)

    def test_up_down_dots(self):
        expected_value_colors = (
            "<p>Down:"
            "<span style='color: #FF0000; font-size:25px;'>&#8718;</span>"
            "|Up:"
            "<span style='color: #00FF00; font-size:25px;'>&#8718;</span>"
            "</p>")
        result = prepare_value_color_html("Down:#FF0000|Up:#00FF00")
        self.assertEqual(result, expected_value_colors)

    def test_multi_color_dots_equal_on_upper_bound(self):
        expected_value_colors = (
            "<p>&le;0:not plot"
            "|&le;1:"
            "<span style='color: #FFFF00; font-size:25px;'>&#8718;</span>"
            "|&le;2:"
            "<span style='color: #00FF00; font-size:25px;'>&#8718;</span>"
            "|2&lt;:"
            "<span style='color: #FF00FF; font-size:25px;'>&#8718;</span>"
            "</p>")
        result = prepare_value_color_html(
            '<=0:not plot|<=1:#FFFF00|<=2:#00FF00|2<:#FF00FF')
        self.assertEqual(result, expected_value_colors)

    def test_multi_color_dots_equal_on_lower_bound(self):
        expected_value_colors = (
            "<p>&lt;3:not plot"
            "|&lt;3.3:"
            "<span style='color: #FFFF00; font-size:25px;'>&#8718;</span>"
            "|=3.3:"
            "<span style='color: #00FF00; font-size:25px;'>&#8718;</span>"
            "</p>")
        result = prepare_value_color_html(
            '<3:not plot|<3.3:#FFFF00|=3.3:#00FF00')
        self.assertEqual(result, expected_value_colors)

    def test_tri_color_lines(self):
        expected_value_colors = (
            "<p>-1:"
            "<span style='color: #FF00FF; font-size:25px;'>&#8718;</span>"
            "|0:<span style='color: #FF0000; font-size:25px;'>&#8718;</span>"
            "|1:<span style='color: #00FF00; font-size:25px;'>&#8718;</span>"
            "</p>"
        )
        result = prepare_value_color_html('-1:#FF00FF|0:#FF0000|1:#00FF00')
        self.assertEqual(result, expected_value_colors)

    def test_dot_for_time(self):
        expected_value_colors = (
            "<p>C:"
            "<span style='color: #FF00FF; font-size:25px;'>&#8718;</span>"
            "</p>"
        )
        result = prepare_value_color_html('C:#FF00FF')
        self.assertEqual(result, expected_value_colors)

    def test_empty_input(self):
        expected = ''
        actual = prepare_value_color_html('')
        self.assertEqual(expected, actual)
